#
# spec file for package xh
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xh
Version:        0.24.0
Release:        1.3
Summary:        Tool for sending HTTP requests
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/ducaale/xh
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  libopenssl-devel

%description
xh is a tool for sending HTTP requests. It reimplements as much as possible of HTTPie's design, with a focus on improved performance.

%prep
%autosetup -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%files
%{_bindir}/%{name}

%changelog
* Tue Feb 25 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.24.0:
  Features:
  * Add --generate option to generate the man page and shell completions at runtime, see #393
  * Add support for Elvish and Nushell shell completions, see #393
  * Add --compress for compressing request body, see #403
  Bug fixes:
  * Store default paths for cookies without an explicit path attribute, see #401
  Other:
  * Support generating man page with reproducible timestamp via SOURCE_DATE_EPOCH, see #402
  * Upgrade cookie_store to 0.21.1, see #397
* Wed Jan  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.23.1:
  Security fixes:
  * Upgrade to ruzstd v0.7.3 to fix RUSTSEC-2024-0400, see #396
  Bug fixes:
  * Warn on combination of --continue and Range header, #394
  Other:
  * Enable logging in rustls and tracing-using dependencies, see #390
* Tue Oct 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.23.0:
  Features:
  * Handle responses compressed in zstd format, see #364
  * Suppress warnings when -qq flag is used, see #371
  * Add --debug option for logging and backtraces, see #371
  * Decode content-disposition and location headers as UTF-8, see #375
  * Print headers as latin1, with the UTF-8 decoding also shown if applicable, see #377
  * Print the actual reason phrase sent by the server instead of guessing it from the status code, see #377
  Bug fixes:
  * Apply TLS options to non-HTTPS URLs, see #372
  Other:
  * Ignore NO_COLOR if set to empty string, see #370
* Wed Jul 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.2:
  * Prevent directory traversal in server-supplied filenames #379
* Mon Apr 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.0:
  Features:
  * Support http2-prior-knowledge, see #356
  * Directly bind to interface name on supported platforms, see #359
  * Enable stream when content-type is text/event-stream, see #360
  * Decode utf-8 encoded string when formatting non-streaming JSON response, see #361
  Other:
  * Upgrade to hyper v1, see #357
  * Use serde-transcode to optimize JSON formatting, see #362
* Mon Jan 29 2024 Michael Vetter <mvetter@suse.com>
- Updat to 0.21.0:
  * Display remote address in metadata when -vv or --meta flag is
    used, see #348
  * Default XH_CONFIG_DIR to ~/.config/xh in macOS, see #353
* Sun Nov 19 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.20.1:
  * Add --resolve for overriding DNS resolution #327
* Mon Oct 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.19.4:
  * Explicitly enable serde's derive feature, see #334
- Disable tests since they need an internet connection
* Mon Oct 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.19.3:
  * Make network-interface an optional dependency, see #332
* Mon Oct 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.19.2:
  * Add --interface for binding to a local IP address or interface, see #307
  * Translate --raw flag when using --curl, see #308
  * Support duplicate header keys in session files, see #313
  * Support persisting cookies from multiple domains, see #314
  * Control output formatting (JSON indent-level, header sorting, etc)
    via --format-options, see #318 and #319
  * Disable cURL's URL globbing, see #325
  * Improve PATH handling in install.ps1, see #264
  * Update Rustls to v0.21.0, see #311
* Tue Oct 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.19.1:
  * Add --interface for binding to a local IP address or interface #307
  * Translate --raw flag when using --curl #308
  * Support duplicate header keys in session files #313
  * Support persisting cookies from multiple domains #314
  * Control output formatting (JSON indent-level, header sorting, etc)
    via --format-options #318 #319)
  * Disable cURL's URL globbing #325
  * Improve PATH handling in install.ps1 #264
  * Update Rustls to v0.21.0 #311
* Tue Feb 21 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  Features:
  * Support reading query param and header values from a file, see #288[1]
  * Highlight Syntax errors found while tokenizing a JSON path, see #260[3]
  * Support outputting the metadata of a response via --meta, --print=m or -vv, see #240[4]
  Bug fixes:
  * Fix panic when when parsing connection timeout, see #295[5]
  Breaking changes:
  * Remove -m as a short flag for --multipart, see #299[7]
* Wed Jan 11 2023 Michael Vetter <mvetter@suse.com>
- Initial package of xh 0.17.0 for openSUSE
